

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

int main(int argc, const char* argv[])
{
    if (argc != 3) {
        fprintf(stderr, "usage: gauss_weight std_dev_length std_dev_cutoff\n");
        exit(1);
    }
    float std_dev_length = atof(argv[1]);
    float std_dev_cutoff = atof(argv[2]);

    float offset = exp(-(std_dev_cutoff * std_dev_cutoff * 0.5));

    float weight1 = 0.0;
    float weight2 = 0.0;

    int resolution = 1000;
    int max_std_dev = 5;
    for (int i = 0; i <= 2 * max_std_dev * resolution; i++) {
        float dev = (i - max_std_dev * resolution) / ((float) resolution);
        if (fabs(dev) >= std_dev_cutoff) {
            continue;
        }
        weight1 += exp(-(dev * dev * 0.5));
        weight2 += exp(-(dev * dev * 0.5)) - offset;
    }

    float weight_factor1 = resolution / (std_dev_length * weight1);
    float weight_factor2 = resolution / (std_dev_length * weight2);
    printf("stddev %.3f, cutoff %.3f, no offset, weight factor: %.5f\n",
        std_dev_length, std_dev_cutoff, weight_factor1);
    printf("stddev %.3f, cutoff %.3f, zero crossing (%.3f), weight factor: %.5f\n",
        std_dev_length, std_dev_cutoff, offset, weight_factor2);

    return 0;
}


